﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ManDressEvidence
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private ObservableCollection<Dress> dresses = new ObservableCollection<Dress>();
        private bool modified = false;
        public MainWindow()
        {
            InitializeComponent();
            Data.ItemsSource = dresses;
        }

        private void NewItem_Click(object sender, RoutedEventArgs e)
        {
            dresses.Clear();
            DressCountLabel.Text = "0";
            modified = false;
        }

        private void OpenItem_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            if (dialog.ShowDialog() == true)
            {
                LoadData(dialog.FileName);
            }
        }

        private void LoadData(string filename)
        {
            using(StreamReader reader = new StreamReader(filename))
            {
                string line = reader.ReadLine();
                while(line  != null)
                {
                    Dress dress = Dress.parse(line);
                    dresses.Add(dress);
                    DressCountLabel.Text = dresses.Count.ToString();
                    line = reader.ReadLine();
                }
            }
        }

        private void SaveItem_Click(object sender, RoutedEventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            if (dialog.ShowDialog() == true)
            {
                SaveData(dialog.FileName);
            }
        }

        private void SaveData(string filename)
        {
            using(StreamWriter writer = new StreamWriter(filename))
            {
                foreach(Dress dress in dresses)
                {
                    writer.WriteLine(dress);
                }
                modified = false;
            }
        }

        private void ExitItem_Click(object sender, RoutedEventArgs e)
        {
            if (modified)
            {
                MessageBox.Show("Mate neulozena data. Nejdrive je ulozte.");
                return;
            }
            Application.Current.Shutdown();
        }

        private void AddDress_Click(object sender, RoutedEventArgs e)
        {
            AddDressDialog dialog = new AddDressDialog();
            if (dialog.ShowDialog() == true)
            {
                Dress dress = dialog.DressProp;
                dresses.Add(dress);
                DressCountLabel.Text = dresses.Count.ToString();
                modified = true;
            }

        }
    }
}
